@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-"""This module contains a object that represents a Telegram File."""
+"""This module contains an object that represents a Telegram File."""
 
 from os.path import basename
 
@@ -34,21 +34,19 @@ class File(TelegramObject):
     Args:
         file_id (str):
         bot (telegram.Bot):
-        **kwargs: Arbitrary keyword arguments.
-
-    Keyword Args:
         file_size (Optional[int]):
         file_path (Optional[str]):
+        **kwargs (dict): Arbitrary keyword arguments.
 
     """
 
-    def __init__(self, file_id, bot, **kwargs):
+    def __init__(self, file_id, bot, file_size=0, file_path='', **kwargs):
         # Required
         self.file_id = str(file_id)
 
         # Optionals
-        self.file_size = int(kwargs.get('file_size', 0))
-        self.file_path = str(kwargs.get('file_path', ''))
+        self.file_size = int(file_size)
+        self.file_path = str(file_path)
 
         self.bot = bot
 
