@@ -23,6 +23,35 @@ from telegram import InlineQueryResult, InlineKeyboardMarkup, InputMessageConten
 
 
 class InlineQueryResultGif(InlineQueryResult):
+    """Represents a link to an animated GIF file. By default, this animated GIF file will be sent
+    by the user with optional caption. Alternatively, you can use input_message_content to send a
+    message with the specified content instead of the animation.
+
+    Attributes:
+        gif_url (str): A valid URL for the GIF file. File size must not exceed 1MB.
+        thumb_url (str): URL of the static thumbnail for the result (jpeg or gif).
+        gif_width (Optional[int]): Width of the GIF.
+        gif_height (Optional[int]): Height of the GIF.
+        title (Optional[str]): Title for the result.
+        caption	(Optional[str]): Caption of the GIF file to be sent, 0-200 characters.
+        reply_markup (Optional[:class:`telegram.InlineKeyboardMarkup`]): Inline keyboard attached
+            to the message.
+        input_message_content (Optional[:class:`telegram.InputMessageContent`]): Content of the
+            message to be sent instead of the GIF animation.
+
+    Args:
+        id (str):
+        gif_url (str):
+        thumb_url (str):
+        gif_width (Optional[int]):
+        gif_height (Optional[int]):
+        title (Optional[str]):
+        caption	(Optional[str]):
+        reply_markup (Optional[:class:`telegram.InlineKeyboardMarkup`]):
+        input_message_content (Optional[:class:`telegram.InputMessageContent`]):
+        **kwargs (dict): Arbitrary keyword arguments.
+
+    """
 
     def __init__(self,
                  id,
